First of these optimizations rolled out in v1.15.0 with a reduced scope. Next version of oxlint will be even faster: github.com/oxc-project/... On my laptop: ~15% faster on `oven-sh/bun`, ~9% faster on `microsoft/vscode`, ~11% faster on `posthog/posthog`, and ~8% faster on `elastic/kibana`
github.comperf(linter): detect node types from `let..else` statements by camchenry · Pull Request #13690 · oxc-project/oxcpart of linter: dynamically skip running rules that do not have the relevant node types #12223
Adds basic detection for syntax like let AstKind::Something(...) = node.kind() else { return }; in li...
Trying some new oxlint optimizations. This PR has gone over several iterations in the last few months and the core idea is simple: don't run rules for files if they don't apply (using an AST node bitset lookup). The result: linting is around 15% faster in practice.
2 reposts27 likes